<?php
/**
 * @package		Auto Archive
 * @subpackage	plg_system_autoarchive
 *
 * @author		Helios Ciancio <info@eshiol.it>
 * @link		http://www.eshiol.it
 * @copyright	Copyright (C) 2017 Helios Ciancio. All Rights Reserved
 * @license		http://www.gnu.org/licenses/gpl-3.0.html GNU/GPL v3
 * AutoArchive for Joomla! is free software. This version may have been 
 * modified pursuant to the GNU General Public License, and as distributed
 * it includes or is derivative of works licensed under the GNU General Public
 * License or other free or open source software licenses.
 */

// no direct access
defined('_JEXEC') or die('Restricted access.');

jimport('joomla.plugin.plugin');

class plgSystemAutoarchive extends JPlugin
{
	/**
	 * Load the language file on instantiation.
	 *
	 * @var    boolean
	 */
	protected $autoloadLanguage = true;

	/**
	 * Constructor
	 *
	 * @param  object  $subject  The object to observe
	 * @param  array   $config   An array that holds the plugin configuration
	 */
	function __construct(&$subject, $config)
	{
		parent::__construct($subject, $config);

		if ($this->params->get('debug') || defined('JDEBUG') && JDEBUG)
		{
			JLog::addLogger(array('text_file' => $this->params->get('log', 'eshiol.log.php'), 'extension' => 'plg_system_autoarchive_file'), JLog::ALL, array('plg_system_autoarchive'));
		}
		JLog::addLogger(array('logger' => (null !== $this->params->get('logger')) ? $this->params->get('logger') : 'messagequeue', 'extension' => 'plg_system_autoarchive'), JLOG::ALL & ~JLOG::DEBUG, array('plg_system_autoarchive'));
		if ($this->params->get('phpconsole') && class_exists('JLogLoggerPhpconsole'))
		{
			JLog::addLogger(array('logger' => 'phpconsole', 'extension' => 'plg_system_autoarchive_phpconsole'),  JLOG::DEBUG, array('plg_system_autoarchive'));
		}
		JLog::add(new JLogEntry(__METHOD__, JLog::DEBUG, 'plg_system_autoarchive'));
	}

	/**
	 *  
	 *
	 * @return  void
	 */
	public function onAfterInitialise()
	{
		JLog::add(new JLogEntry(__METHOD__, JLog::DEBUG, 'plg_system_autoarchive'));

		try
		{
			$db = JFactory::getDbo();
			$nowDate = $db->q(JFactory::getDate()->toSql());
			$query = $db->getQuery(true)
				->select($db->qn('v.item_id'))
				->from($db->qn('#__fields').' f')
				->innerJoin($db->qn('#__fields_values').' v ON f.id = v.field_id')
				->innerJoin($db->qn('#__content').' a ON v.item_id = a.id')
				->where($db->qn('f.context').' = '.$db->q('com_content.article'))
				->where($db->qn('f.name').' = '.$db->q('plg-system-autoarchive-date'))
				->where($db->qn('v.value'))
				->where($db->qn('v.value').' <= '.$nowDate)
				->where($db->qn('a.state').' = 1');
			JLog::add(new JLogEntry($query, JLog::DEBUG, 'plg_system_autoarchive'));
			$db->setQuery($query);
			if ($idsToArchive = $db->loadColumn(0))
			{
				$session = JFactory::getSession();
				$user = $session->get('user');
				$admin = JUser::getInstance($this->params->get('system'));
				if ($admin->id)
				{
					JLog::add(new JLogEntry('archiving articles '.implode(', ', $idsToArchive), JLog::DEBUG, 'plg_system_autoarchive'));
					$session->set('user', $admin);
					JLoader::import('joomla.application.component.model');
					JModelLegacy::addIncludePath(JPATH_ADMINISTRATOR . '/components/com_content/models', 'ContentModel');
					$model = JModelLegacy::getInstance('Article', 'ContentModel');
					$model->publish($idsToArchive, 2);
					$session->set('user', $user);
				}
				else
				{
					JLog::add(new JLogEntry('user not found', JLog::DEBUG, 'plg_system_autoarchive'));
				}
			}
		}
		catch (Exception $e)
		{
			$this->setError($e->getMessage());

			return false;
		}
	}
}
	