<?php
/**
 * @package		Auto Archive
 * @subpackage	plg_system_autoarchive
 * @version		3.8.3
 * @since		3.7.0
 *
 * @author		Helios Ciancio <info@eshiol.it>
 * @link		http://www.eshiol.it
 * @copyright	Copyright (C) 2017, 2018 Helios Ciancio. All Rights Reserved
 * @license		http://www.gnu.org/licenses/gpl-3.0.html GNU/GPL v3
 * AutoArchive for Joomla! is free software. This version may have been 
 * modified pursuant to the GNU General Public License, and as distributed
 * it includes or is derivative of works licensed under the GNU General Public
 * License or other free or open source software licenses.
 */
 
// no direct access
defined('_JEXEC') or die('Restricted access.');

class PlgSystemAutoarchiveInstallerScript
{
	/**
	 * Called after any type of action
	 *
	 * @param   string      $action     Which action is happening (install|uninstall|discover_install|update)
	 * @param   JInstaller  $installer  The class calling this method
	 *
	 * @return  boolean  True on success
	 *
	 * @since   3.7
	 */
	public function postflight($action, $installer)
	{
		JLog::add(new JLogEntry(__METHOD__, JLog::DEBUG, 'plg_system_autoarchive'));
	
		if (($action === 'install') or ($action === 'update'))
		{
			JTable::addIncludePath(JPATH_ROOT.'/administrator/components/com_fields/tables');

			// Initialize a new field
			/** @type  FieldsTableField  $field  */
			$field = JTable::getInstance('Field', 'FieldsTable');

			// Check if the field archive_up exists before adding it
			if (!$field->load(array('context' => 'com_content.article', 'name' => 'plg-system-autoarchive-date')))
			{
				$field->context = 'com_content.article';
				$field->group_id = 0;
				$field->title = 'archive_up';
				$field->name = 'plg-system-autoarchive-date';
				$field->label = 'PLG_SYSTEM_AUTOARCHIVE_ARCHIVEUP_LABEL';
				$field->default_value = '';
				$field->type = 'calendar';
				$field->note = '';
				$field->description = '';
				$field->state = 1;
				$field->required = 0;
				$field->params = '{"hint":"","render_class":"","class":"","showlabel":"1","show_on":"2","display":"2"}';
				$field->fieldparams = '{"showtime":"1"}';
				$field->language = '*';
				$field->created_user_id = JFactory::getUser()->id;
				$field->access = 1;
				// Check to make sure our data is valid
				if (!$field->check())
				{
					JFactory::getApplication()->enqueueMessage(JText::sprintf('PLG_SYSTEM_AUTOARCHIVE_CREATE_FIELD_ERROR', $field->getError()));
					return false;
				}
				// Now store the category
				if (!$field->store(true))
				{
					JFactory::getApplication()->enqueueMessage(JText::sprintf('PLG_SYSTEM_AUTOARCHIVE_CREATE_FIELD_ERROR', $field->getError()));
					return false;
				}
				JLog::add(new JLogEntry(JText::sprintf('PLG_SYSTEM_AUTOARCHIVE_CREATE_FIELD_OK', $field->title), JLog::DEBUG, 'plg_system_autoarchive'));
			}
			if ($action == 'install')
			{
				// Enable plugin
				$db = JFactory::getDbo();
				$query = $db->getQuery(true);
				$query->update('#__extensions')
					->set($db->qn('enabled') . ' = 1')
					->where($db->qn('type') . ' = ' . $db->q('plugin'))
					->where($db->qn('element') . ' = ' . $db->q('autoarchive'))
					->where($db->qn('folder') . ' = ' . $db->q('system'));
				$db->setQuery($query)
					->execute();
			}
		}
	}
}